@@ -1,7 +1,6 @@
 package yahoo
 
 import (
-	"fmt"
 	"strings"
 
 	c "github.com/achannarasappa/ticker/internal/common"
@@ -19,7 +18,7 @@ func transformResponseCurrency(responseQuote ResponseQuote) c.CurrencyRate {
 	return c.CurrencyRate{
 		FromCurrency: fromCurrency,
 		ToCurrency:   toCurrency,
-		Rate:         responseQuote.RegularMarketPrice,
+		Rate:         responseQuote.RegularMarketPrice.Raw,
 	}
 
 }
@@ -40,14 +39,12 @@ func transformResponseCurrencies(responseQuotes []ResponseQuote) c.CurrencyRates
 func getCurrencyRatesFromCurrencyPairSymbols(client resty.Client, currencyPairSymbols []string) (c.CurrencyRates, error) {
 
 	symbolsString := strings.Join(currencyPairSymbols, ",")
-	url := fmt.Sprintf("https://query1.finance.yahoo.com/v6/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&fields=regularMarketPrice,currency&symbols=%s", symbolsString)
 
 	res, err := client.R().
 		SetResult(Response{}).
-		SetHeader("Host", "query1.finance.yahoo.com").
-		SetHeader("accept", "*/*").
-		SetHeader("user-agent", "curl/7.68.0").
-		Get(url)
+		SetQueryParam("fields", "regularMarketPrice,currency").
+		SetQueryParam("symbols", symbolsString).
+		Get("/v7/finance/quote")
 
 	if err != nil {
 		return c.CurrencyRates{}, err
@@ -78,13 +75,12 @@ func transformResponseCurrencyPairs(responseQuotes []ResponseQuote, targetCurren
 func getCurrencyPairSymbols(client resty.Client, symbols []string, targetCurrency string) ([]string, error) {
 
 	symbolsString := strings.Join(symbols, ",")
-	url := fmt.Sprintf("https://query1.finance.yahoo.com/v6/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&fields=regularMarketPrice,currency&symbols=%s", symbolsString)
+
 	res, err := client.R().
 		SetResult(Response{}).
-		SetHeader("Host", "query1.finance.yahoo.com").
-		SetHeader("accept", "*/*").
-		SetHeader("user-agent", "curl/7.68.0").
-		Get(url)
+		SetQueryParam("fields", "regularMarketPrice,currency").
+		SetQueryParam("symbols", symbolsString).
+		Get("/v7/finance/quote")
 
 	if err != nil {
 		return []string{}, err
